@@ -9,48 +9,53 @@ from subprocess import run as subprocess_run
 import venv
 from urllib.request import urlretrieve
 
-from k2s.parse import (extract_imports_from_notebook, download_files,
-                       extract_code)
+from k2s.parse import extract_imports_from_notebook, download_files, extract_code
 
 from k2s.subprocess import _run_command
 
 
 def path_to_bin(env_name, bin):
-    dir = 'Scripts' if os.name == 'nt' else 'bin'
-    bin_name = f'{bin}.exe' if os.name == 'nt' else bin
+    dir = "Scripts" if os.name == "nt" else "bin"
+    bin_name = f"{bin}.exe" if os.name == "nt" else bin
     return str(Path(env_name, dir, bin_name))
 
 
-def from_url(url):
+def from_url(url, open_jupyter=True):
     """
 
     >>> from k2s.bootstrap import from_url; from_url("URL")
     """
-    url = f'https://raw.githubusercontent.com/{url}'
+    GITHUB_COM = "https://github.com"
+
+    if not url.startswith("http"):
+        url = f"https://raw.githubusercontent.com/{url}"
+    elif url.startswith(GITHUB_COM):
+        url = url.replace(GITHUB_COM, "https://raw.githubusercontent.com")
+        url = url.replace("blob/", "")
 
     file = PurePosixPath(url).name
     urlretrieve(url, file)
 
-    return from_file(file, url=url)
+    return from_file(file, url=url, open_jupyter=True)
 
 
-def from_file(file, url=None):
-    env_name = Path(file).stem + '-env'
+def from_file(file, url=None, open_jupyter=True):
+    env_name = Path(file).stem + "-env"
 
-    nb = json.loads(Path(file).read_text(encoding='utf-8'))
+    nb = json.loads(Path(file).read_text(encoding="utf-8"))
 
-    if 'metadata' not in nb:
-        nb['metadata'] = {}
+    if "metadata" not in nb:
+        nb["metadata"] = {}
 
-    if not nb['metadata'].get('kernelspec'):
-        print('Notebook is missing kernel information, assuming Python...')
-        nb['metadata']['kernelspec'] = {
+    if not nb["metadata"].get("kernelspec"):
+        print("Notebook is missing kernel information, assuming Python...")
+        nb["metadata"]["kernelspec"] = {
             "display_name": "Python 3 (ipykernel)",
             "language": "python",
-            "name": "python3"
+            "name": "python3",
         }
 
-        Path(file).write_text(json.dumps(nb), encoding='utf-8')
+        Path(file).write_text(json.dumps(nb), encoding="utf-8")
 
     deps = extract_imports_from_notebook(nb)
 
@@ -65,8 +70,10 @@ def from_file(file, url=None):
 
     print("Creating virtual environment...")
     print(f"Installing: {', '.join(deps)}")
-    print("This may take a moment. "
-          "Join our community while you wait: https://ploomber.io/community")
+    print(
+        "This may take a moment. "
+        "Join our community while you wait: https://ploomber.io/community"
+    )
 
     # if the user stopped the process in the middle and tried again, the env
     # might exist but will be corrupted, so we must clean it
@@ -79,29 +86,33 @@ def from_file(file, url=None):
     # the virtual environment
     venv.create(env_name, with_pip=True, system_site_packages=False)
 
-    path_to_python = path_to_bin(env_name, 'python')
+    path_to_python = path_to_bin(env_name, "python")
 
     subprocess_run(
-        [path_to_python, '-m', 'pip', 'install', 'pip', '--upgrade'],
+        [path_to_python, "-m", "pip", "install", "pip", "--upgrade"],
         check=True,
-        capture_output=True)
+        capture_output=True,
+    )
 
-    _run_command([path_to_python, '-m', 'pip', 'install', 'jupyterlab'] + deps)
+    if open_jupyter:
+        deps = deps + ["jupyterlab"]
+
+    _run_command([path_to_python, "-m", "pip", "install"] + deps)
+
+    if not open_jupyter:
+        return
 
     print("Lauching Jupyter... (this might take a few seconds)")
 
     # TODO: if jupyter lab is already installed, we can use it (and skip
     # installation), but we have to make sure that the kernel used is
     # the one in the venv, not in the parent env
-    path_to_jupyterlab = path_to_bin(env_name, 'jupyter-lab')
+    path_to_jupyterlab = path_to_bin(env_name, "jupyter-lab")
 
-    print('To exit: CTRL + C')
+    print("To exit: CTRL + C")
 
     try:
-        subprocess_run([path_to_jupyterlab, file],
-                       check=True,
-                       capture_output=True)
+        subprocess_run([path_to_jupyterlab, file], check=True, capture_output=True)
     except KeyboardInterrupt:
-        print('Exiting...')
-        print(f'\nTo laucnh again:\n\n'
-              f'{path_to_jupyterlab} {file}')
+        print("Exiting...")
+        print(f"\nTo launch again:\n\n" f"{path_to_jupyterlab} {file}")
