@@ -6,14 +6,13 @@ from k2s.exceptions import CLIError
 
 
 class CLI:
-
     def __init__(self) -> None:
         parser = argparse.ArgumentParser()
-        parser.add_argument('command')
+        parser.add_argument("command")
         args = parser.parse_args(sys.argv[1:2])
 
         if not hasattr(self, args.command):
-            sys.exit(f'Unrecognized command {args.command!r}')
+            sys.exit(f"Unrecognized command {args.command!r}")
         else:
             cmd = getattr(self, args.command)
 
@@ -26,6 +25,7 @@ class CLI:
 
     def get(self):
         parser = argparse.ArgumentParser()
-        parser.add_argument('url')
+        parser.add_argument("url")
+        parser.add_argument("--no-jupyter", action="store_true")
         args = parser.parse_args(sys.argv[2:])
-        from_url(args.url)
+        from_url(args.url, open_jupyter=not args.no_jupyter)
